//
// Software License for AMDiS
//
// Copyright (c) 2010 Dresden University of Technology 
// All rights reserved.
// Authors: Simon Vey, Thomas Witkowski et al.
//
// This file is part of AMDiS
//
// See also license.opensource.txt in the distribution.


#include "parallel/CheckerPartitioner.h"
#include "Traverse.h"


namespace AMDiS {

  void CheckerPartitioner::createInitialPartitioning()
  {
    FUNCNAME("CheckerPartitioner::createInitialPartitioning()");

    int mpiRank = mpiComm->Get_rank();
    int mpiSize = mpiComm->Get_size();

    int nElementsPerBlock = (mesh->getDim() == 2 ? 2 : 6);

    MSG("ELS_PER_BLOCK = %d\n", nElementsPerBlock);

    TraverseStack stack;
    ElInfo *elInfo = stack.traverseFirst(mesh, 0, Mesh::CALL_EL_LEVEL);
    while (elInfo) {
      Element *el = elInfo->getElement();
      int elIndex = el->getIndex();
      int elInRank = elIndex / nElementsPerBlock;
      TEST_EXIT_DBG(elInRank < mpiSize)("Should not happen!\n");

      if (elInRank == mpiRank) {
	MSG("EL %d IS MY!\n", elIndex);
      } else {
	MSG("EL %d IS IN RANK %d\n", elIndex, elInRank);
      }

      elementInRank[elIndex] = (elInRank == mpiRank);
      partitionMap[elIndex] = elInRank;	
	
      elInfo = stack.traverseNext(elInfo);
    }
  }

}
